"""The mesh module of dolfin"""
import meshes
import ale
import refinement

from meshes import *
from ale import *
from refinement import *

# NOTE: The automatic documentation system in DOLFIN requires to _not_
# NOTE: define classes or functions within this file. Use separate
# NOTE: modules for that purpose.

__all__ = meshes.__all__ + ale.__all__ + refinement.__all__
